@@ -2,8 +2,6 @@ package App::Base::Daemon;
 use 5.010;
 use Moose::Role;
 with 'App::Base::Script::Common';
-our $VERSION = "0.04";
-$VERSION = eval $VERSION;
 
 =head1 NAME
 
@@ -11,7 +9,7 @@ App::Base::Daemon - A lazy person's tool for writing self-documenting, self-moni
 
 =head1 VERSION
 
-This document describes App::Base version 0.04
+This document describes App::Base version 0.05
 
 =head1 SYNOPSIS
 
@@ -28,7 +26,7 @@ This document describes App::Base version 0.04
     sub daemon_run {
         my $self = shift;
         while (1) {
-            $self->info( 'The foo option is', $self->getOption('foo') );
+            # do something
             sleep(1)
         }
 
@@ -37,7 +35,7 @@ This document describes App::Base version 0.04
 
     sub handle_shutdown {
         my $self = shift;
-        $self->warning("I am shutting down now");
+        # do something
         return 0;
     }
 
@@ -213,7 +211,6 @@ around 'base_options' => sub {
 sub _signal_shutdown {
     my $self = shift;
     my $sig  = shift;
-    $self->info("Received SIG$sig, shutting down");
     $self->handle_shutdown;
     exit 0;
 }
@@ -229,7 +226,7 @@ sub __run {
             if ( $self->can_do_hot_reload ) {
                 chomp( my $pid = try { my $fh = path( $self->pid_file )->openr; <$fh>; } );
                 if ( $pid and kill USR2 => $pid ) {
-                    $self->warning("Daemon is alredy running, initiated hot reload");
+                    warn("Daemon is alredy running, initiated hot reload");
                     exit 0;
                 }
                 else {
@@ -238,7 +235,7 @@ sub __run {
                 }
             }
             else {
-                Carp::croak( "Couldn't lock "
+                die(  "Couldn't lock "
                       . $self->pid_file
                       . ". Is another copy of this daemon already running?" );
             }
@@ -254,13 +251,13 @@ sub __run {
     unless ( $self->getOption('no-fork') or $hot_reload ) {
         my $child_pid = fork();
         if ( !defined($child_pid) ) {
-            Carp::croak("Can't fork child process: $!");
+            die("Can't fork child process: $!");
         }
         elsif ( $child_pid == 0 ) {
             POSIX::setsid();
             my $grandchild_pid = fork();
             if ( !defined($grandchild_pid) ) {
-                Carp::croak("Can't fork grandchild process: $!");
+                die("Can't fork grandchild process: $!");
             }
             elsif ( $grandchild_pid != 0 ) {
                 $pid->close if $pid;
@@ -318,15 +315,13 @@ sub _set_user_and_group {
             }
             if ($gid) {
                 POSIX::setgid($gid);
-                $self->info("Changed group to $group");
             }
             if ($uid) {
                 POSIX::setuid($uid);
-                $self->info("Changed user to $user");
             }
         }
         else {
-            $self->warning("Not running as root, can't setuid/setgid");
+            warn("Not running as root, can't setuid/setgid");
         }
     }
 
@@ -343,7 +338,7 @@ result in shutting down your daemon, use warn() instead.
 
 sub error {
     my $self = shift;
-    $self->logger->error( "Shutting down: " . join( ' ', @_ ) );
+    warn( "Shutting down: " . join( ' ', @_ ) );
 
     $self->handle_shutdown();
     return exit(-1);
